@@ -1,4 +1,5 @@
 import datetime
+import logging
 import random
 
 from lemmings import Task
@@ -58,8 +59,8 @@ class TaskSet(object, metaclass=TaskSetMeta):
                 ordered += 1
         if ordered > 0:
             if ordered != len(self.tasks):
-                print(f"WARNING! Found only {ordered} ordered task(s) from {len(self.tasks)} total")
-                print("To run tasks as sequence, all tasks should be ordered")
+                logging.warning(f"WARNING! Found only {ordered} ordered task(s) from {len(self.tasks)} total")
+                logging.warning("To run tasks as sequence, all tasks should be ordered")
             else:
                 return True
         return False
